#ifndef NT2_INCLUDE_FUNCTIONS_FAM_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FAM_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/fam.hpp>

#endif
